Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch splpmap() -> splvm()



details:   https://anonhg.NetBSD.org/src/rev/d3f106eda0ee
branches:  trunk
changeset: 502222:d3f106eda0ee
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Sun Jan 14 02:03:48 2001 +0000

description:
splpmap() -> splvm()

diffstat:

 sys/arch/sparc/sparc/pmap.c     |  50 ++++++++++++++++++----------------------
 sys/arch/sparc64/sparc64/pmap.c |   6 ++--
 sys/arch/sun3/sun3/pmap.c       |  36 +++++++++++++---------------
 3 files changed, 43 insertions(+), 49 deletions(-)

diffs (truncated from 405 to 300 lines):

diff -r f3f23fcf4f5e -r d3f106eda0ee sys/arch/sparc/sparc/pmap.c
--- a/sys/arch/sparc/sparc/pmap.c       Sun Jan 14 02:00:37 2001 +0000
+++ b/sys/arch/sparc/sparc/pmap.c       Sun Jan 14 02:03:48 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap.c,v 1.174 2000/09/09 10:24:34 pk Exp $ */
+/*     $NetBSD: pmap.c,v 1.175 2001/01/14 02:03:48 thorpej Exp $ */
 
 /*
  * Copyright (c) 1996
@@ -154,10 +154,6 @@
 int    pmapdebug = 0;
 #endif
 
-#if 0
-#define        splpmap() splimp()
-#endif
-
 /*
  * First and last managed physical addresses.
  */
@@ -1599,7 +1595,7 @@
                unsigned int tva = VA_ROUNDDOWNTOREG(va);
                struct segmap *sp = rp->rg_segmap;
 
-               s = splpmap();          /* paranoid */
+               s = splvm();            /* paranoid */
                smeg = region_alloc(&region_lru, pm, vr)->me_cookie;
                setregmap(tva, smeg);
                i = NSEGRG;
@@ -1622,7 +1618,7 @@
 
        /* reload segment: write PTEs into a new LRU entry */
        va = VA_ROUNDDOWNTOSEG(va);
-       s = splpmap();          /* paranoid */
+       s = splvm();            /* paranoid */
        pmeg = me_alloc(&segm_lru, pm, vr, vs)->me_cookie;
        setsegmap(va, pmeg);
        i = NPTESG;
@@ -1664,7 +1660,7 @@
                gap_end = pm->pm_gap_end;
        }
 
-       s = splpmap();
+       s = splvm();
        if ((c = ctx_freelist) != NULL) {
                ctx_freelist = c->c_nextfree;
                cnum = c - cpuinfo.ctxinfo;
@@ -1911,7 +1907,7 @@
 
        write_user_windows();           /* paranoid? */
 
-       s = splpmap();                  /* paranoid? */
+       s = splvm();                    /* paranoid? */
        if (pv0->pv_pmap == NULL) {
                splx(s);
                return;
@@ -2008,7 +2004,7 @@
 
        write_user_windows();           /* paranoid? */
 
-       s = splpmap();                  /* paranoid? */
+       s = splvm();                    /* paranoid? */
        if (pv0->pv_pmap == NULL) {     /* paranoid */
                splx(s);
                return (0);
@@ -2234,7 +2230,7 @@
 
        write_user_windows();           /* paranoid? */
 
-       s = splpmap();                  /* paranoid? */
+       s = splvm();                    /* paranoid? */
        if (pv0->pv_pmap == NULL) {
                splx(s);
                return;
@@ -2318,7 +2314,7 @@
 
        write_user_windows();           /* paranoid? */
 
-       s = splpmap();                  /* paranoid? */
+       s = splvm();                    /* paranoid? */
        if (pv0->pv_pmap == NULL) {     /* paranoid */
                splx(s);
                return (0);
@@ -2524,7 +2520,7 @@
 
        write_user_windows();   /* paranoia? */
 
-       s = splpmap();          /* XXX extreme paranoia */
+       s = splvm();            /* XXX extreme paranoia */
        if ((pm = pv->pv_pmap) != NULL) {
                ctx = getcontext();
                for (;;) {
@@ -3748,7 +3744,7 @@
        struct pmap *pm;
 {
        union ctxinfo *c;
-       int s = splpmap();      /* paranoia */
+       int s = splvm();        /* paranoia */
 
 #ifdef DEBUG
        if (pmapdebug & PDB_DESTROY)
@@ -3876,7 +3872,7 @@
        }
 
        ctx = getcontext();
-       s = splpmap();          /* XXX conservative */
+       s = splvm();            /* XXX conservative */
        simple_lock(&pm->pm_lock);
        for (; va < endva; va = nva) {
                /* do one virtual segment at a time */
@@ -4462,7 +4458,7 @@
         * The logic is much like that for pmap_remove,
         * but we know we are removing exactly one page.
         */
-       s = splpmap();
+       s = splvm();
        if (pv->pv_pmap == NULL) {
                splx(s);
                return;
@@ -4636,7 +4632,7 @@
 
        write_user_windows();
        ctx = getcontext4();
-       s = splpmap();
+       s = splvm();
        simple_lock(&pm->pm_lock);
 
        for (va = sva; va < eva;) {
@@ -4745,7 +4741,7 @@
                newprot = prot & VM_PROT_WRITE ? PG_W : 0;
        vr = VA_VREG(va);
        vs = VA_VSEG(va);
-       s = splpmap();          /* conservative */
+       s = splvm();            /* conservative */
        rp = &pm->pm_regmap[vr];
        if (rp->rg_nsegmap == 0) {
                printf("pmap_changeprot: no segments in %d\n", vr);
@@ -4864,7 +4860,7 @@
         * The logic is much like that for pmap_remove,
         * but we know we are removing exactly one page.
         */
-       s = splpmap();
+       s = splvm();
        if (pv->pv_pmap == NULL) {
                splx(s);
                return;
@@ -4988,7 +4984,7 @@
 
        write_user_windows();
        ctx = getcontext4m();
-       s = splpmap();
+       s = splvm();
        simple_lock(&pm->pm_lock);
 
        for (va = sva; va < eva;) {
@@ -5083,7 +5079,7 @@
 
        pmap_stats.ps_changeprots++;
 
-       s = splpmap();          /* conservative */
+       s = splvm();            /* conservative */
 
        rp = &pm->pm_regmap[VA_VREG(va)];
        sp = &rp->rg_segmap[VA_VSEG(va)];
@@ -5211,7 +5207,7 @@
        vs = VA_VSEG(va);
        rp = &pm->pm_regmap[vr];
        sp = &rp->rg_segmap[vs];
-       s = splpmap();          /* XXX way too conservative */
+       s = splvm();            /* XXX way too conservative */
 
 #if defined(SUN4_MMU3L)
        if (HASSUN4_MMU3L && rp->rg_smeg == reginval) {
@@ -5335,7 +5331,7 @@
        vr = VA_VREG(va);
        vs = VA_VSEG(va);
        rp = &pm->pm_regmap[vr];
-       s = splpmap();                  /* XXX conservative */
+       s = splvm();                    /* XXX conservative */
 
        /*
         * If there is no space in which the PTEs can be written
@@ -5630,7 +5626,7 @@
        rp = &pm->pm_regmap[vr];
        sp = &rp->rg_segmap[vs];
 
-       s = splpmap();          /* XXX way too conservative */
+       s = splvm();            /* XXX way too conservative */
 
        if (rp->rg_seg_ptps == NULL) /* enter new region */
                panic("pmap_enk4m: missing kernel region table for va 0x%lx",va);
@@ -5713,7 +5709,7 @@
        vr = VA_VREG(va);
        vs = VA_VSEG(va);
        rp = &pm->pm_regmap[vr];
-       s = splpmap();                  /* XXX conservative */
+       s = splvm();                    /* XXX conservative */
 
 rretry:
        if (rp->rg_segmap == NULL) {
@@ -6786,7 +6782,7 @@
         * the new context.
         */
 
-       s = splpmap();
+       s = splvm();
        if (p == curproc) {
                write_user_windows();
                if (pmap->pm_ctx == NULL) {
@@ -7124,7 +7120,7 @@
        int s, pte0, pte, ctx;
        vaddr_t va;
 
-       s = splpmap();
+       s = splvm();
        va = (unsigned long)dst & (~PGOFSET);
        cpuinfo.cache_flush(dst, 1);
 
diff -r f3f23fcf4f5e -r d3f106eda0ee sys/arch/sparc64/sparc64/pmap.c
--- a/sys/arch/sparc64/sparc64/pmap.c   Sun Jan 14 02:00:37 2001 +0000
+++ b/sys/arch/sparc64/sparc64/pmap.c   Sun Jan 14 02:03:48 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap.c,v 1.88 2001/01/03 23:05:22 eeh Exp $    */
+/*     $NetBSD: pmap.c,v 1.89 2001/01/14 02:03:49 thorpej Exp $        */
 #undef NO_VCACHE /* Don't forget the locked TLB in dostart */
 #define        HWREF
 /*
@@ -1836,7 +1836,7 @@
         * the new context.
         */
 
-       s = splpmap();
+       s = splvm();
        if (p == curproc) {
                write_user_windows();
                if (pmap->pm_ctx == NULL)
@@ -3417,7 +3417,7 @@
 #endif
                return (0);
        }
-       s = splpmap();
+       s = splvm();
        cnum = next;
        do {
                if (cnum >= numctx-1) 
diff -r f3f23fcf4f5e -r d3f106eda0ee sys/arch/sun3/sun3/pmap.c
--- a/sys/arch/sun3/sun3/pmap.c Sun Jan 14 02:00:37 2001 +0000
+++ b/sys/arch/sun3/sun3/pmap.c Sun Jan 14 02:03:48 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap.c,v 1.121 2000/11/24 11:57:45 tsutsui Exp $       */
+/*     $NetBSD: pmap.c,v 1.122 2001/01/14 02:03:50 thorpej Exp $       */
 
 /*-
  * Copyright (c) 1996 The NetBSD Foundation, Inc.
@@ -271,14 +271,12 @@
 #define pmap_refcount(pmap) pmap->pm_refcount
 
 /*
  * Note that splpmap() is used in routines called at splnet() and
  * MUST NOT lower the priority.  For this reason we arrange that:
  *    splimp = max(splnet,splbio)
  * Would splvm() be more natural here? (same level as splimp).
  */
 
-#define splpmap splimp
-
 #ifdef PMAP_DEBUG
 #define        CHECK_SPL() do { \
        if ((getsr() & PSL_IPL) < PSL_IPL4) \
@@ -2029,7 +2027,7 @@
 {
        int s;
 
-       s = splpmap();
+       s = splvm();
 
        if (pmap == kernel_pmap)
                panic("pmap_release: kernel_pmap!");
@@ -2147,7 +2145,7 @@
         *   be in the mmu either.
         *
         */
-       s = splpmap();
+       s = splvm();
        if (pmap == kernel_pmap) {
                new_pte |= PG_SYSTEM;
                pmap_enter_kernel(va, new_pte, wired);
@@ -2605,7 +2603,7 @@
                chkpte |= PG_WRITE;
        rv = 0;
 
-       s = splpmap();
+       s = splvm();
 
        /*
         * Given that we faulted on a user-space address, we will
@@ -2675,7 +2673,7 @@
        pv_flags = pa_to_pvflags(pa);
        head     = pa_to_pvhead(pa);
@@ -271,14 +271,12 @@
 
 /*
- * Note that splpmap() is used in routines called at splnet() and
+ * Note that splvm() is used in routines called at splnet() and
  * MUST NOT lower the priority.  For this reason we arrange that:
  *    splimp = max(splnet,splbio)



Home | Main Index | Thread Index | Old Index